@@ -87,12 +87,10 @@ export function addExtensionReducers() {
     addExtraMiddleware(secretAPI.middleware);
   }
 
-  if (config.featureToggles.pluginsFrontendSandbox) {
-    addRootReducer({
-      [sandboxSettingsAPI.reducerPath]: sandboxSettingsAPI.reducer,
-    });
-    addExtraMiddleware(sandboxSettingsAPI.middleware);
-  }
+  addRootReducer({
+    [sandboxSettingsAPI.reducerPath]: sandboxSettingsAPI.reducer,
+  });
+  addExtraMiddleware(sandboxSettingsAPI.middleware);
 
   if (config.featureToggles.queryLibrary) {
     addRootReducer({
@@ -359,9 +357,7 @@ function initEnterprise() {
     });
   }
 
-  if (config.featureToggles.pluginsFrontendSandbox) {
-    initSandboxPluginLoaderRegistry();
-  }
+  initSandboxPluginLoaderRegistry();
 
   if (config.featureToggles.queryLibrary) {
     initQueryLibrary();
