@@ -40,7 +40,7 @@ import {
   useNamespaceAndGroupOptions,
 } from '../../components/rules/Filter/useRuleFilterAutocomplete';
 import { useRulesFilter } from '../../hooks/useFilteredRules';
-import { RuleHealth, getSearchFilterFromQuery } from '../../search/rulesSearchParser';
+import { RuleHealth, RuleSource, getSearchFilterFromQuery } from '../../search/rulesSearchParser';
 
 import { RulesFilterProps } from './RulesFilter';
 import {
@@ -53,6 +53,8 @@ import {
 
 const canRenderContactPointSelector = contextSrv.hasPermission(AccessControlAction.AlertingReceiversRead);
 
+const radioGroupCompactClass = css({ width: 'max-content' });
+
 type SearchQueryForm = {
   query: string;
 };
@@ -78,7 +80,7 @@ export default function RulesFilter({ viewMode, onViewModeChange }: RulesFilterP
 
   const submitHandler: SubmitHandler<SearchQueryForm> = (values: SearchQueryForm) => {
     const parsedFilter = getSearchFilterFromQuery(values.query);
-    trackAlertRuleFilterEvent({ filterMethod: 'search-input', filter: parsedFilter });
+    trackAlertRuleFilterEvent({ filterMethod: 'search-input', filter: parsedFilter, filterVariant: 'v2' });
     updateFilters(parsedFilter);
   };
 
@@ -160,6 +162,7 @@ export default function RulesFilter({ viewMode, onViewModeChange }: RulesFilterP
                     'Search by name or enter filter query...'
                   )}
                   name="searchQuery"
+                  escapeRegex={false}
                   onChange={(next) => {
                     trackRulesSearchInputCleared(field.value, next);
                     field.onChange(next);
@@ -173,7 +176,11 @@ export default function RulesFilter({ viewMode, onViewModeChange }: RulesFilterP
                   onBlur={() => {
                     const currentQuery = field.value;
                     const parsedFilter = getSearchFilterFromQuery(currentQuery);
-                    trackAlertRuleFilterEvent({ filterMethod: 'search-input', filter: parsedFilter });
+                    trackAlertRuleFilterEvent({
+                      filterMethod: 'search-input',
+                      filter: parsedFilter,
+                      filterVariant: 'v2',
+                    });
                     updateFilters(parsedFilter);
                   }}
                   value={field.value}
@@ -244,7 +251,7 @@ const FilterOptions = ({ onSubmit, onClear, pluginsFilterEnabled }: FilterOption
   const { namespaceOptions, allGroupNames, isLoadingNamespaces, namespacePlaceholder, groupPlaceholder } =
     useNamespaceAndGroupOptions();
 
-  const { labelOptions, isLoadingGrafanaLabels } = useLabelOptions();
+  const { labelOptions } = useLabelOptions();
 
   // Create label options for the multi-select dropdown
   const dataSourceOptions = useAlertingDataSourceOptions();
@@ -283,11 +290,7 @@ const FilterOptions = ({ onSubmit, onClear, pluginsFilterEnabled }: FilterOption
         <Stack direction="column" alignItems="end" gap={2}>
           <div className={styles.grid}>
             <RuleNameField />
-            <LabelsField
-              labelOptions={labelOptions}
-              isLoadingGrafanaLabels={isLoadingGrafanaLabels}
-              portalContainer={portalContainer}
-            />
+            <LabelsField labelOptions={labelOptions} portalContainer={portalContainer} />
             <NamespaceField
               namespaceOptions={namespaceOptions}
               namespacePlaceholder={namespacePlaceholder}
@@ -302,6 +305,7 @@ const FilterOptions = ({ onSubmit, onClear, pluginsFilterEnabled }: FilterOption
             />
             <DataSourceNamesField dataSourceOptions={dataSourceOptions} portalContainer={portalContainer} />
             {canRenderContactPointSelector && <ContactPointField portalContainer={portalContainer} />}
+            <RuleSourceField />
             <RuleStateField />
             <RuleTypeField />
             <RuleHealthField />
@@ -335,11 +339,9 @@ function RuleNameField() {
 
 function LabelsField({
   labelOptions,
-  isLoadingGrafanaLabels,
   portalContainer,
 }: {
-  labelOptions: Array<{ label?: string; value: string; infoOption?: boolean }>;
-  isLoadingGrafanaLabels: boolean;
+  labelOptions: (inputValue: string) => Promise<Array<{ label?: string; value: string; infoOption?: boolean }>>;
   portalContainer?: HTMLElement;
 }) {
   const { control } = useFormContext<AdvancedFilters>();
@@ -356,13 +358,7 @@ function LabelsField({
             options={labelOptions}
             value={field.value}
             onChange={(selections) => field.onChange(selections.map((s) => s.value))}
-            placeholder={
-              isLoadingGrafanaLabels
-                ? t('common.loading', 'Loading...')
-                : t('alerting.rules-filter.placeholder-labels', 'Select labels')
-            }
-            loading={isLoadingGrafanaLabels}
-            disabled={isLoadingGrafanaLabels || labelOptions.filter((option) => !option.infoOption).length === 0}
+            placeholder={t('alerting.rules-filter.placeholder-labels', 'Select labels')}
             portalContainer={portalContainer}
             width="auto"
             minWidth={40}
@@ -380,7 +376,7 @@ function NamespaceField({
   isLoadingNamespaces,
   portalContainer,
 }: {
-  namespaceOptions: Array<{ label?: string; value: string; description?: string }>;
+  namespaceOptions: (inputValue: string) => Promise<Array<{ label?: string; value: string; description?: string }>>;
   namespacePlaceholder: string;
   isLoadingNamespaces: boolean;
   portalContainer?: HTMLElement;
@@ -402,7 +398,6 @@ function NamespaceField({
               onChange={(option) => field.onChange(option?.value || null)}
               value={field.value}
               loading={isLoadingNamespaces}
-              disabled={isLoadingNamespaces || namespaceOptions.length === 0}
               isClearable
               portalContainer={portalContainer}
             />
@@ -441,7 +436,6 @@ function GroupField({
               onChange={(option) => field.onChange(option?.value || null)}
               value={field.value}
               loading={isLoadingNamespaces}
-              disabled={isLoadingNamespaces || allGroupNames.length === 0}
               isClearable
               portalContainer={portalContainer}
             />
@@ -456,7 +450,7 @@ function DataSourceNamesField({
   dataSourceOptions,
   portalContainer,
 }: {
-  dataSourceOptions: Array<{ label?: string; value: string }>;
+  dataSourceOptions: (inputValue: string) => Promise<Array<{ label?: string; value: string }>>;
   portalContainer?: HTMLElement;
 }) {
   const { control } = useFormContext<AdvancedFilters>();
@@ -584,6 +578,8 @@ function RuleStateField() {
             ]}
             value={field.value}
             onChange={field.onChange}
+            fullWidth={false}
+            className={radioGroupCompactClass}
           />
         )}
       />
@@ -610,6 +606,39 @@ function RuleTypeField() {
             ]}
             value={field.value}
             onChange={field.onChange}
+            fullWidth={false}
+            className={radioGroupCompactClass}
+          />
+        )}
+      />
+    </>
+  );
+}
+
+function RuleSourceField() {
+  const { control } = useFormContext<AdvancedFilters>();
+  return (
+    <>
+      <Label>
+        <Trans i18nKey="alerting.search.property.rule-source">Rule source</Trans>
+      </Label>
+      <Controller
+        name="ruleSource"
+        control={control}
+        render={({ field }) => (
+          <RadioButtonGroup<AdvancedFilters['ruleSource']>
+            options={[
+              { label: t('common.all', 'All'), value: null },
+              { label: t('alerting.rules-filter.rule-source.grafana', 'Grafana managed'), value: RuleSource.Grafana },
+              {
+                label: t('alerting.rules-filter.rule-source.datasource', 'Data source managed'),
+                value: RuleSource.DataSource,
+              },
+            ]}
+            value={field.value}
+            onChange={field.onChange}
+            fullWidth={false}
+            className={radioGroupCompactClass}
           />
         )}
       />
@@ -637,6 +666,8 @@ function RuleHealthField() {
             ]}
             value={field.value}
             onChange={field.onChange}
+            fullWidth={false}
+            className={radioGroupCompactClass}
           />
         )}
       />
@@ -662,6 +693,8 @@ function PluginsField() {
             ]}
             value={field.value}
             onChange={field.onChange}
+            fullWidth={false}
+            className={radioGroupCompactClass}
           />
         )}
       />
@@ -697,7 +730,10 @@ function SearchQueryHelp() {
         />
         <HelpRow title={t('alerting.search-query-help.title-group', 'Group')} expr="group:cpu-usage" />
         <HelpRow title={t('alerting.search-query-help.title-rule', 'Rule')} expr='rule:"cpu 80%"' />
-        <HelpRow title={t('alerting.search-query-help.title-labels', 'Labels')} expr="label:team=A label:cluster=a1" />
+        <HelpRow
+          title={t('alerting.search-query-help.title-labels', 'Labels')}
+          expr='label:team=A label:"cluster=new york"'
+        />
         <HelpRow title={t('alerting.search-query-help.title-state', 'State')} expr="state:firing|normal|pending" />
         <HelpRow title={t('alerting.search-query-help.title-type', 'Type')} expr="type:alerting|recording" />
         <HelpRow title={t('alerting.search-query-help.title-health', 'Health')} expr="health:ok|nodata|error" />
